@@ -14,14 +14,16 @@ use base qw(Verilog::Parser);
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.310';
+$VERSION = '3.311';
 
 our @_Callback_Names = qw(
   attribute
+  class
   contassign
   covergroup
   defparam
   endcell
+  endclass
   endgroup
   endinterface
   endmodport
@@ -103,6 +105,13 @@ sub contassign {
     my $rhs = shift;
 }
 
+sub class {
+    my $self = shift;
+    my $keyword = shift;
+    my $name = shift;
+    my $virtual = shift;
+}
+
 sub covergroup {
     my $self = shift;
     my $keyword = shift;
@@ -115,6 +124,10 @@ sub defparam {
     my $rhs = shift;
 }
 
+sub endclass {
+    my $self = shift;
+}
+
 sub endcell {
     my $self = shift;
 }
@@ -300,6 +313,10 @@ of each comment line (C<//key rest> to end of line) or comment block
 (C</*key rest */).  It calls C<$self->attribute( meta_text )>
 if the first word has a true value in hash C<$self->metacomment>.
 
+=item $self->class ( $token, $name, $virtual )
+
+This method is called at a class.
+
 =item $self->covergroup ( $token, $name )
 
 This method is called at a covergroup.
@@ -331,6 +348,11 @@ writing clean up routines.
 This method is called at a endinterface keyword. It is useful for writing
 clean up routines.
 
+=item $self->endclass ( $token )
+
+This method is called at a endclass keyword.  It is useful for writing
+clean up routines.
+
 =item $self->endtaskfunc ( $token )
 
 This method is called at a endfunction or endtask keyword.  It is useful
